==> gthumb-2.4.1.tar.gz: gthumb-2.4.1/libgthumb/gthumb-stock.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef GTHUMB_STOCK_H
#define GTHUMB_STOCK_H

#define GTHUMB_STOCK_ADD_COMMENT          "gthumb-add-comment"
#define GTHUMB_STOCK_BRIGHTNESS_CONTRAST  "gthumb-brightness-contrast"
#define GTHUMB_STOCK_CAMERA               "gthumb-camera"
#define GTHUMB_STOCK_COLOR_BALANCE        "gthumb-color-balance"
#define GTHUMB_STOCK_CROP                 "gthumb-crop"
#define GTHUMB_STOCK_DESATURATE           "gthumb-desaturate"
#define GTHUMB_STOCK_ENHANCE              "gthumb-enhance"
#define GTHUMB_STOCK_EDIT_IMAGE           "gthumb-edit-image"
#define GTHUMB_STOCK_FILM                 "gthumb-film"
#define GTHUMB_STOCK_FLIP                 "gthumb-flip"
#define GTHUMB_STOCK_FULLSCREEN           "gthumb-fullscreen"
#define GTHUMB_STOCK_HISTOGRAM            "gthumb-histogram"
#define GTHUMB_STOCK_HUE_SATURATION       "gthumb-hue-saturation"
#define GTHUMB_STOCK_IMAGE                "gthumb-image"
#define GTHUMB_STOCK_INVERT               "gthumb-invert"
#define GTHUMB_STOCK_LEVELS               "gthumb-levels"
#define GTHUMB_STOCK_MIRROR               "gthumb-mirror"
#define GTHUMB_STOCK_NORMAL_VIEW          "gthumb-normal-view"
#define GTHUMB_STOCK_POSTERIZE            "gthumb-posterize"
#define GTHUMB_STOCK_PROPERTIES           "gthumb-properties"
#define GTHUMB_STOCK_RESET                "gthumb-reset"
#define GTHUMB_STOCK_RESIZE               "gthumb-resize"
#define GTHUMB_STOCK_ROTATE               "gthumb-rotate"
#define GTHUMB_STOCK_ROTATE_90            "gthumb-rotate-90"
#define GTHUMB_STOCK_ROTATE_90_CC         "gthumb-rotate-90-cc"
#define GTHUMB_STOCK_SLIDESHOW            "gthumb-slideshow"
#define GTHUMB_STOCK_SWAP                 "gthumb-swap"
#define GTHUMB_STOCK_THRESHOLD            "gthumb-threshold"
#define GTHUMB_STOCK_TRANSFORM            "gthumb-transform"


void gthumb_stock_init (void);


#endif /* GTHUMB_STOCK_H */

==> gthumb-2.7.3.tar.gz: gthumb-2.7.3/libgthumb/gthumb-stock.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2001, 2003, 2004 Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#ifndef GTHUMB_STOCK_H
#define GTHUMB_STOCK_H

#define GTHUMB_STOCK_ADD_COMMENT          "gthumb-add-comment"
#define GTHUMB_STOCK_ADD_TO_CATALOG       "gthumb-add-to-catalog"
#define GTHUMB_STOCK_BOOKMARK             "gthumb-bookmark"
#define GTHUMB_STOCK_BRIGHTNESS_CONTRAST  "gthumb-brightness-contrast"
#define GTHUMB_STOCK_CAMERA               "gthumb-camera"
#define GTHUMB_STOCK_CATALOG              "gthumb-catalog"
#define GTHUMB_STOCK_CHANGE_DATE          "gthumb-change-date"
#define GTHUMB_STOCK_COLOR_BALANCE        "gthumb-color-balance"
#define GTHUMB_STOCK_CROP                 "gthumb-crop"
#define GTHUMB_STOCK_DESATURATE           "gthumb-desaturate"
#define GTHUMB_STOCK_ENHANCE              "gthumb-enhance"
#define GTHUMB_STOCK_EDIT_IMAGE           "gthumb-edit-image"
#define GTHUMB_STOCK_FILM                 "gthumb-film"
#define GTHUMB_STOCK_FLIP                 "gthumb-flip"
#define GTHUMB_STOCK_FULLSCREEN           "gthumb-fullscreen"
#define GTHUMB_STOCK_HISTOGRAM            "gthumb-histogram"
#define GTHUMB_STOCK_HUE_SATURATION       "gthumb-hue-saturation"
#define GTHUMB_STOCK_IMAGE                "gthumb-image"
#define GTHUMB_STOCK_INDEX_IMAGE          "gthumb-index-image"
#define GTHUMB_STOCK_INVERT               "gthumb-invert"
#define GTHUMB_STOCK_LEVELS               "gthumb-levels"
#define GTHUMB_STOCK_MIRROR               "gthumb-mirror"
#define GTHUMB_STOCK_NEXT_IMAGE           "gthumb-next-image"
#define GTHUMB_STOCK_NORMAL_VIEW          "gthumb-normal-view"
#define GTHUMB_STOCK_POSTERIZE            "gthumb-posterize"
#define GTHUMB_STOCK_PREVIOUS_IMAGE       "gthumb-previous-image"
#define GTHUMB_STOCK_REDUCE_COLORS        "gthumb-reduce-colors"
#define GTHUMB_STOCK_RESET                "gthumb-reset"
#define GTHUMB_STOCK_RESIZE               "gthumb-resize"
#define GTHUMB_STOCK_ROTATE               "gthumb-rotate"
#define GTHUMB_STOCK_ROTATE_90            "gthumb-rotate-90"
#define GTHUMB_STOCK_ROTATE_90_CC         "gthumb-rotate-90-cc"
#define GTHUMB_STOCK_SEARCH               "gthumb-search"
#define GTHUMB_STOCK_SHOW_CATALOGS        "gthumb-show-catalogs"
#define GTHUMB_STOCK_SHOW_IMAGE           "gthumb-show-image"
#define GTHUMB_STOCK_SLIDESHOW            "gthumb-slideshow"
#define GTHUMB_STOCK_SWAP                 "gthumb-swap"
#define GTHUMB_STOCK_THRESHOLD            "gthumb-threshold"
#define GTHUMB_STOCK_TRANSFORM            "gthumb-transform"


void gthumb_stock_init (void);


#endif /* GTHUMB_STOCK_H */
